# Data Feed Adapter Spec

This page is currently maintained in Chinese first.

- Chinese page: [DataFeedAdapter 规范草案](../../zh/advanced/data_feed_adapter_spec.md)
- Related code: [feed_adapter.py](https://github.com/akfamily/akquant/blob/main/python/akquant/feed_adapter.py)
- Related docs:
  - [Multi-Timeframe Feed API](multi_timeframe_feed_api.md)
  - [Capability Boost Plan](capability_boost_plan.md)
